@@ -2,7 +2,7 @@
 DSLIBRARY - run your data science code anywhere.
 
 """
-__version__ = "0.0.73"
+__version__ = "0.0.74"
 
 import re
 
@@ -120,6 +120,8 @@ load_dataframe = _DEFAULT.load_dataframe
 save_dataframe = _DEFAULT.save_dataframe
 open_resource = _DEFAULT.open_resource
 write_resource = _DEFAULT.write_resource
+sql_select = _DEFAULT.sql_select
+sql_exec = _DEFAULT.sql_exec
 log_metric = _DEFAULT.log_metric
 log_metrics = _DEFAULT.log_metrics
 log_param = _DEFAULT.log_param
