@@ -23,7 +23,8 @@ import threading
 from .exceptions import DSLibraryDataFormatException, DSLibraryException
 from .engine_intf import GenericStreamWrapper, BytesIOWrapper
 from .proto_handlers import load_protocol_handler
-from .utils.connect import connect_to_database, dataframe_to_sql, db_conn_flavor
+from .utils.connect import connect_to_database, db_conn_flavor
+from .sql.data_to_sql import dataframe_to_sql
 from .utils.csp_connect import connect_to_csp
 from .sql.misc import sql_enquote_id
 from .utils.df_utils import CloseAfterIteration, load_dataframe_from_sql, LoadStrategy, coerce_to_dataframe, \
