@@ -96,7 +96,7 @@ class DSLibraryViaMMLibrary(DSLibrary):
         Opening of streams goes through the get/save resource methods.
         """
         # these patterns indicate obviously local files
-        if path.startswith("./") or path.startswith("/"):
+        if path.startswith("./"):
             return open(path, mode)
         # obvious URL of external source
         if "://" in path:
@@ -109,8 +109,6 @@ class DSLibraryViaMMLibrary(DSLibrary):
             return write_stream_with_read_on_close(w_mode=mode, r_mode='rb', on_close=finalize)
         # for read we fully load the data and make a stream
         if "r" in mode:
-            # ignore path - resources have 'simple' names
-            path = path.split("/")[-1]
             try:
                 reader = self._find_method("get_binary_from_resource", "getBinaryFromResource")
                 if mode == 'rb':
@@ -120,7 +118,7 @@ class DSLibraryViaMMLibrary(DSLibrary):
                 raise FileNotFoundError(f"not found: {path}")
         raise DSLibraryException(f"Unsupported mode: {mode}")
 
-    def open_model_binary(self, part: str=None, mode: str='rb') -> io.RawIOBase:
+    def open_model_binary(self, part: str=None, mode: str='rb') -> io.  IOBase:
         """
         The model-binary is just one file, but we can support 'part' by assuming it is a ZIP file.
         """
