@@ -12,16 +12,17 @@ import os
 import threading
 import time
 
-from ..exceptions import DSLibraryCommunicationError
+from ..exceptions import *
 from .to_rest import DSLibraryViaREST
 
 
 class DSLibraryViaVolume(DSLibraryViaREST):
-    def __init__(self, volume: str, spec: dict=None, _env: dict=None):
+    def __init__(self, volume: str, spec: dict=None, _env: dict=None, response_wait_interval=0.01):
         super(DSLibraryViaVolume, self).__init__(url="", spec=spec)
         self._volume = volume
         self._request_no = 0
         self._lock = threading.Lock()
+        self._response_wait_interval = response_wait_interval
 
     class Response(object):
         def __init__(self, content: bytes):
@@ -41,6 +42,7 @@ class DSLibraryViaVolume(DSLibraryViaREST):
             self._request_no += 1
             fn_rqst = os.path.join(self._volume, f"rqst_{self._request_no}.json")
             fn_resp = fn_rqst + ".response"
+            fn_resp_meta = fn_rqst + ".response-meta"
             rqst = {
                 "method": method, "path": path, "params": params, "data": data, "timeout": t_timeout, "as_json": as_json
             }
@@ -53,11 +55,37 @@ class DSLibraryViaVolume(DSLibraryViaREST):
             # now we wait for a response...
             try:
                 while True:
-                    time.sleep(0.01)
+                    time.sleep(self._response_wait_interval)
                     if time.time() > t_timeout:
                         raise DSLibraryCommunicationError(f"timeout waiting for {path} request")
-                    if os.path.exists(fn_resp):
+                    if os.path.exists(fn_resp_meta):
                         try:
+                            # read metadata, determine response type
+                            with open(fn_resp_meta, 'rb') as f_r:
+                                meta = json.load(f_r)
+                            xfer = meta.get("xfer")
+                            if as_json is None:
+                                as_json = xfer == "json"
+                            # detect error
+                            if "error_class" in meta:
+                                err_c = meta["error_class"]
+                                err_a = meta["error_args"]
+                                err_cls = None
+                                if err_c in globals():
+                                    err_cls = globals()[err_c]
+                                elif hasattr(__builtins__, err_c):
+                                    err_cls = getattr(__builtins__, err_c)
+                                else:
+                                    # FIXME weirdly, this works but the above does not
+                                    try:
+                                        err_cls = __builtins__[err_c]
+                                    except:
+                                        pass
+                                if not issubclass(err_cls, Exception):
+                                    err_cls = Exception.__class__
+                                    err_a.append(err_c)
+                                raise err_cls(*err_a)
+                            # read response
                             with open(fn_resp, 'rb') as f_r:
                                 if as_json:
                                     resp = json.load(f_r)
@@ -71,5 +99,3 @@ class DSLibraryViaVolume(DSLibraryViaREST):
                 os.remove(fn_rqst)
                 if os.path.exists(fn_resp):
                     os.remove(fn_resp)
-
-
