@@ -35,6 +35,16 @@ class FileOpener(object):
         :return:        A stream, if the supplied arguments were supported, or None.
         """
         if path.startswith("https://") or path.startswith("http://") or path.startswith("ftp://"):
+            if "?" in mode:
+                if "w" in mode:
+                    return True
+                try:
+                    # TODO a HEAD would be better to check existence than starting a full transfer and abandoning it
+                    strm = self.http_open(path, mode.replace("?", ""), **kwargs)
+                    strm.close()
+                    return True
+                except:
+                    return False
             allowed = ("data", "timeout", "cafile", "cadefault", "context")
             use_kwargs = {k: v for k, v in kwargs.items() if k in allowed}
             if mode == "rb":
@@ -72,6 +82,11 @@ class FileOpener(object):
             kwargs = kwargs["storage_options"]
         if path.startswith("s3:") and mode and "a" in mode:
             raise ValueError(f"Append mode is not supported for {path}")
+        if "?" in mode:
+            if "w" in mode:
+                return True
+            fss = connect_to_filesystem(path, **kwargs)
+            return fss.exists(path)
         return fsspec.open(path, mode=mode, **kwargs)
 
     def local_open(self, path: str, mode: str, **kwargs):
@@ -83,6 +98,11 @@ class FileOpener(object):
         :return:    A file stream.
         """
         full_path = os.path.join(self._root, path)
+        if "?" in mode:
+            if "w" in mode:
+                folder = os.path.split(full_path)[0]
+                return os.path.exists(folder or ".")
+            return os.path.exists(full_path)
         return open(full_path, mode)
 
     def open(self, path: str, mode: str, **kwargs):
@@ -96,13 +116,15 @@ class FileOpener(object):
         """
         # some really simple external file access can be handled without fsspec
         stream = self.http_open(path, mode, **kwargs)
-        if stream:
+        if stream is not None:
             return stream
         # URIs go through fsspec
         stream = self.uri_open(path, mode, **kwargs)
-        if stream:
+        if stream is not None:
             return stream
         # local files
+        if ":" in path:
+            raise ValueError(f"Unsupported URL: {path}")
         return self.local_open(path, mode, **kwargs)
 
 
@@ -195,6 +217,33 @@ def is_breakout_path(path: str) -> bool:
     return False
 
 
+def join_uri_path(base_uri: str, *paths_to_add, no_breakout: bool=True) -> str:
+    """
+    Like os.path.join(), only with support for URIs/URLs.
+
+    Unlike os.path.join(), paths starting with '/' will not discard all prior paths, the '/' will be ignored.
+
+    :param base_uri:        The folder or URL to append to.
+    :param paths_to_add:    Path elements to add.
+    :return:        New path or URL.
+    """
+    if "?" in base_uri:
+        out, after = base_uri.split("?", maxsplit=1)
+        after = "?" + after
+    elif "#" in base_uri:
+        out, after = base_uri.split("#", maxsplit=1)
+        after = "#" + after
+    else:
+        out, after = base_uri, ""
+    for path in paths_to_add:
+        if is_breakout_path(path) and no_breakout:
+            raise ValueError(f"invalid path element: {path}")
+        if not out.endswith("/"):
+            out += "/"
+        out += path.strip("/")
+    return out + after
+
+
 KNOWN_FSSPEC_STORAGE_OPTIONS = {
     "access_key": "key", "secret_key": "secret", "service_account": "service_account",
     "account_name": "account_name", "account_key": "account_key"
